@@ -80,7 +80,7 @@
 #'   V.Q. de Souza, and E. Jost. 2019a. Mean performance and stability in
 #'   multi-environment trials I: Combining features of AMMI and BLUP techniques.
 #'   Agron. J. 111:2949-2960.
-#'   \href{https://dl.sciencesocieties.org/publications/aj/abstracts/0/0/agronj2019.03.0220?access=0&view=pdf}{doi:10.2134/agronj2019.03.0220}
+#' \href{https://acsess.onlinelibrary.wiley.com/doi/abs/10.2134/agronj2019.03.0220}{doi:10.2134/agronj2019.03.0220}
 #'
 #'   Shahbazi, E. 2019. Genotype selection and stability analysis for
 #'   seed yield of Nigella sativa using parametric and non-parametric
@@ -138,17 +138,17 @@ ge_stats = function(.data,
       data <- remove_rows_na(data)
       has_text_in_num(data)
     }
-ge_mean = make_mat(data, GEN, ENV, mean)
-ge_effect = ge_effects(data, ENV, GEN, mean)[[1]]
-gge_effect = ge_effects(data, ENV, GEN, mean, type = "gge")[[1]]
-Mean = apply(ge_mean, 1, mean)
-Variance = rowSums(apply(ge_mean, 2, function(x) (x - Mean)^2))
+ge_mean <- make_mat(data, GEN, ENV, mean)
+ge_effect <- ge_effects(data, ENV, GEN, mean)[[1]]
+gge_effect <- ge_effects(data, ENV, GEN, mean, type = "gge")[[1]]
+Mean <- apply(ge_mean, 1, mean)
+Variance <- rowSums(apply(ge_mean, 2, function(x) (x - Mean)^2))
 CV <- apply(ge_mean, 1, function(x) (sd(x) / mean(x) * 100))
-GENSS = (rowSums(ge_mean^2) - (rowSums(ge_mean)^2)/nlevels(data$ENV))*nlevels(data$REP)
-mod = anova(lm(mean ~ REP/ENV + ENV * GEN, data = data))
-GENMS = GENSS / mod[2, 1]
-Fcal =  GENMS / mod[6, 3]
-pval = pf(Fcal, mod[2, 1], mod[6, 1], lower.tail = FALSE)
+GENSS <- (rowSums(ge_mean^2) - (rowSums(ge_mean)^2)/nlevels(data$ENV))*nlevels(data$REP)
+mod <- anova(lm(mean ~ REP/ENV + ENV * GEN, data = data))
+GENMS <- GENSS / mod[2, 1]
+Fcal <- GENMS / mod[6, 3]
+pval <- pf(Fcal, mod[2, 1], mod[6, 1], lower.tail = FALSE)
 er_mod <- ge_reg(data, ENV, GEN, REP, mean, verbose = FALSE)
 ec_mod <- ecovalence(data, ENV, GEN, REP, mean, verbose = FALSE)[[1]]
 an_mod <- Annicchiarico(data, ENV, GEN, REP, mean, verbose = FALSE, prob = prob)
