@@ -279,7 +279,7 @@ path_coeff <- function(.data,
     weightvarname <- paste(rownames(last), collapse = " > ")
     temp <- structure(list(Corr.x = as_tibble(cor.x, rownames = NA),
                            Corr.y = as_tibble(cor.y, rownames = NA),
-                           Coefficients = as_tibble(t(Coeff), rownames = NA),
+                           Coefficients = cbind(as_tibble(t(Coeff), rownames = NA), as_tibble(cor.y, rownames = NA) %>% set_names("linear")),
                            Eigen = as_tibble(AvAvet),
                            VIF =  rownames_to_column(VIF, "VAR") %>% as_tibble(),
                            plot = p1,
@@ -425,7 +425,7 @@ path_coeff <- function(.data,
       cor.y <- data.frame(cor.y)
       Results <- list(Corr.x = data.frame(cor.x),
                       Corr.y = data.frame(cor.y),
-                      Coefficients = data.frame(t(Coeff)),
+                      Coefficients = cbind(data.frame(t(Coeff)), data.frame(cor.y) %>% set_names("linear")),
                       Eigen = AvAvet,
                       VIF = VIF,
                       plot = p1,
