@@ -1,8 +1,21 @@
 #' Additive Main effects and Multiplicative Interaction
 #'
-#' Compute the Additive Main effects and Multiplicative interaction. This
-#' function also serves as a helper function for other procedures performed in
-#' the \pkg{metan} package such as \code{\link{waas}} and \code{\link{wsmp}}
+#' @description
+#' Compute the Additive Main effects and Multiplicative interaction (AMMI)
+#' model. The estimate of the response variable for the *i*th genotype in the
+#' *j*th environment (\mjseqn{y_{ij}}) using the AMMI model, is given as follows:
+#'\loadmathjax
+#'\mjsdeqn{{y_{ij}} = \mu  + {\alpha_i} + {\tau_j} + \sum\limits_{k = 1}^p
+#'{{\lambda_k}{a_{ik}}} {t_{jk}} + {\rho_{ij}} + {\varepsilon _{ij}}}
+#'
+#' where \mjseqn{\lambda_k} is the singular value for the *k*-th interaction
+#' principal component axis (IPCA); \mjseqn{a_{ik}} is the *i*-th element of the
+#' *k*-th eigenvector; \mjseqn{t_{jk}} is the *j*th element of the *k*th
+#' eigenvector. A residual \mjseqn{\rho _{ij}} remains, if not all *p* IPCA are
+#' used, where \mjseqn{p \le min(g - 1; e - 1)}.
+#'
+#' This function also serves as a helper function for other procedures performed
+#' in the \pkg{metan} package such as \code{\link{waas}} and \code{\link{wsmp}}
 #'
 #' @param .data The dataset containing the columns related to Environments,
 #'   Genotypes, replication/block and response variable(s).
@@ -230,15 +243,16 @@ performs_ammi <- function(.data,
                       rename(Code = ENV) %>%
                       cbind(., SCOREE)) %>%
             column_to_first(type, Code)
-        PC <- SSAMMI %>%
+        PC <-
+            SSAMMI %>%
             column_to_last(percent, acum) %>%
             rownames_to_column("Source") %>%
             rename(`Sum Sq` = Sum.Sq,
                    `Mean Sq` = Mean.Sq,
                    `F value` = F.value,
                    `Pr(>F)` = Pr.F,
-                   Percent = percent,
-                   Accumul = acum)
+                   Proportion = percent,
+                   Accumulated = acum)
         resid <- anova[nrow(anova), ]
         anova <- rbind_fill(anova[-nrow(anova), ], PC, resid)
         anova2 <- tibble(Source = "Total",
@@ -247,8 +261,8 @@ performs_ammi <- function(.data,
                          `Mean Sq` = `Sum Sq` / Df,
                          `F value` = NA,
                          `Pr(>F)` = NA,
-                         Percent = NA,
-                         Accumul = NA)
+                         Proportion = NA,
+                         Accumulated = NA)
         anova <- rbind(anova, anova2)
         MeansGxE <- MEANS[, 1:3]
         EscGEN <- subset(bplot, type == "GEN")
