@@ -155,7 +155,7 @@ NULL
 NULL
 
 .onAttach <- function(libname, pkgname) {
-  vers <-  "v1.5.0"
+  vers <-  "v1.6.0"
   packageStartupMessage("[]=====================================================[]")
   packageStartupMessage("[] Multi-Environment Trial Analysis (metan) ", vers, "     []")
   packageStartupMessage("[] Author: Tiago Olivoto                               []")
@@ -189,5 +189,6 @@ if (getRversion() >= "2.15.1") {
       "BLUPge+e+re", "BLUPre", "Estimate", "HMRPGV", "RPGV", "Variance", "blup",
       "intercept", "lower", "upper", "pred_ols", "res_ammi", "res_ols", "pattern",
       "replacement", "comparison", "group1", "group2", "p.adj", "term", "rel_freq",
-      "variable", "Model", "level", "RESIDUAL", "MGIDI", "sd.amo"))
+      "variable", "Model", "level", "RESIDUAL", "MGIDI", "sd.amo", "SD", "SG", "data.x",
+      "data.y", "sense", "win"))
   }
